@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[2]:
+# In[82]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[3]:
+# In[83]:
 
 
-version = '0.46'
+version = '0.47'
 
 import re
 import tempfile
@@ -32,7 +32,7 @@ import stat
 
 # # Helper Functions
 
-# In[4]:
+# In[84]:
 
 
 def is_testing():
@@ -42,7 +42,7 @@ def is_testing():
         return False
 
 
-# In[5]:
+# In[85]:
 
 
 def isnotebook():
@@ -60,7 +60,7 @@ def isnotebook():
 #         pass
 #     return False
 
-# In[6]:
+# In[86]:
 
 
 def testPrint(*args):
@@ -70,7 +70,7 @@ def testPrint(*args):
 
 # # Requiremtns
 
-# In[7]:
+# In[87]:
 
 
 requirements = []
@@ -78,6 +78,9 @@ requirements = []
 requirements.append('numpy')
 import numpy as np
 
+requirements.append('pandas')
+import pandas as pd
+
 requirements.append('natsort')
 import natsort
 
@@ -96,14 +99,14 @@ from IPython.core.display import display, HTML
 
 # # Lists
 
-# In[8]:
+# In[88]:
 
 
 def listsGetPairsFromTwoLists(list1, list2):
     return list(zip(list1, list2))
 
 
-# In[9]:
+# In[89]:
 
 
 if is_testing():
@@ -113,14 +116,14 @@ if is_testing():
     print(listsGetPairsFromTwoLists(listAbcd, list1234))
 
 
-# In[10]:
+# In[90]:
 
 
 def listSequentialOverlappingPairs(l):
     return list(zip(l[:-1], l[1:]))
 
 
-# In[11]:
+# In[91]:
 
 
 if is_testing():
@@ -130,7 +133,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[12]:
+# In[92]:
 
 
 regex_cache = {}
@@ -140,51 +143,74 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[13]:
+# In[93]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[14]:
+# In[94]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[15]:
+# In[95]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[16]:
+# In[96]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[17]:
+# In[97]:
 
 
-def lCsv(l):
+def lCsv(l, force_oneline=False):
+    
+    if len(l) == 0:
+        return ""
+    
+    if all([isinstance(e, (list, tuple)) for e in l]) and not force_oneline:
+        length = len(l[0])
+        if all([len(e) == length for e in l]):
+            return "\n".join([lCsv(e, force_oneline=True) for e in l])
+            
     return ", ".join([str(e) for e in l])
 
 
-# In[18]:
+# In[98]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
+# In[99]:
+
+
+if is_testing():
+    print(lCsv([['a', 'b'], 1, 3.14]))
+
+
+# In[100]:
+
+
+if is_testing():
+    print(lCsv([['a', 'b', 1, 3.14], ['c', 'd', 2, 2.72]]))
+
+
 # # Text files
 
-# In[19]:
+# In[101]:
 
 
 def txtread(path):
@@ -200,7 +226,7 @@ def txtwrite(path, txt):
         return f.write(txt)
 
 
-# In[20]:
+# In[102]:
 
 
 if is_testing():
@@ -209,7 +235,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[21]:
+# In[103]:
 
 
 regex_cache = {}
@@ -221,35 +247,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[22]:
+# In[104]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[23]:
+# In[105]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[24]:
+# In[106]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[25]:
+# In[107]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[26]:
+# In[108]:
 
 
 if is_testing():
@@ -258,7 +284,7 @@ if is_testing():
 
 # # Images
 
-# In[27]:
+# In[109]:
 
 
 def imread(path):
@@ -288,7 +314,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255):
     return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'constant', constant_values=color)
 
 
-# In[28]:
+# In[110]:
 
 
 def imshow(array, scale=1):
@@ -303,7 +329,7 @@ def imshow(array, scale=1):
         cv2.waitKey()
 
 
-# In[29]:
+# In[111]:
 
 
 if is_testing():
@@ -311,14 +337,14 @@ if is_testing():
     imshow(img)
 
 
-# In[30]:
+# In[112]:
 
 
 if is_testing():
     imshow('http://via.placeholder.com/70.png')
 
 
-# In[31]:
+# In[113]:
 
 
 def imscaleNN(img, s):
@@ -328,7 +354,7 @@ def imscaleBic(img, s):
     return cv2.resize(img, None, fx=s, fy=s, interpolation=cv2.INTER_CUBIC)
 
 
-# In[32]:
+# In[114]:
 
 
 if is_testing():
@@ -347,33 +373,33 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[33]:
+# In[115]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[34]:
+# In[116]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[35]:
+# In[117]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[36]:
+# In[118]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[37]:
+# In[119]:
 
 
 def imAddNoiseGauss(img, std):
@@ -385,7 +411,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imread('http://via.placeholder.com/150.png'), 10))
 
 
-# In[38]:
+# In[120]:
 
 
 def imJpgDegradation(img, quality):
@@ -398,7 +424,7 @@ def imJpgDegradation(img, quality):
 if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[39]:
+# In[121]:
 
 
 def imCropCenter(img, size):
@@ -413,35 +439,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[40]:
+# In[122]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[41]:
+# In[123]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[42]:
+# In[124]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[43]:
+# In[125]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[44]:
+# In[126]:
 
 
 def imGallery(imgs, pad=0):
@@ -472,7 +498,7 @@ def imGallery(imgs, pad=0):
     return out
 
 
-# In[45]:
+# In[127]:
 
 
 if is_testing():
@@ -480,49 +506,49 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[46]:
+# In[128]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:1]))
 
 
-# In[47]:
+# In[129]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2]))
 
 
-# In[48]:
+# In[130]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2], pad=1))
 
 
-# In[49]:
+# In[131]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:5], pad=1))
 
 
-# In[50]:
+# In[132]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:9], pad=1))
 
 
-# In[51]:
+# In[133]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1))
 
 
-# In[52]:
+# In[134]:
 
 
 if is_testing():
@@ -532,14 +558,14 @@ if is_testing():
 
 # # Files
 
-# In[53]:
+# In[135]:
 
 
 def fiFindByWildcard(wildcard):
     return natsort.natsorted(glob.glob(wildcard, recursive=True))
 
 
-# In[54]:
+# In[136]:
 
 
 if is_testing():
@@ -568,7 +594,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[55]:
+# In[137]:
 
 
 def fiRemove(path):
@@ -596,7 +622,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[56]:
+# In[138]:
 
 
 if is_testing():
@@ -630,7 +656,21 @@ if is_testing():
 
 # # Jupyter
 
-# In[57]:
+# In[139]:
+
+
+def jnNbFullWidth():
+    from IPython.core.display import display, HTML
+    display(HTML("<style>.container { width:100% !important; }</style>"))
+    
+def jnPandasSettings():
+    pd.set_option('display.max_rows', 500)
+    pd.set_option('display.max_columns', 500)
+    pd.set_option('display.width', 1000)
+    pd.set_option('display.max_colwidth', None)
+
+
+# In[140]:
 
 
 def jnImageRenderingPixelated():
@@ -642,7 +682,19 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[58]:
+# In[141]:
+
+
+def jnDefault():
+    jnNbFullWidth()
+    jnPandasSettings()
+    jnImageRenderingPixelated
+
+if is_testing():
+    jnDefault()
+
+
+# In[142]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -655,7 +707,7 @@ if is_testing():
     
 
 
-# In[59]:
+# In[143]:
 
 
 def jnImgToHtmlB64(img):
@@ -679,7 +731,7 @@ def jnImageRow(imgs, names=None, width=100):
     display(HTML(html))
 
 
-# In[60]:
+# In[144]:
 
 
 if is_testing():
@@ -687,7 +739,7 @@ if is_testing():
    
 
 
-# In[61]:
+# In[145]:
 
 
 
@@ -697,7 +749,7 @@ if is_testing():
 
 # # Shell
 
-# In[62]:
+# In[146]:
 
 
 def shell(cmd):
@@ -712,7 +764,7 @@ def shell(cmd):
 
 # # GIT
 
-# In[63]:
+# In[147]:
 
 
 def gitGetHash():
@@ -722,7 +774,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[64]:
+# In[148]:
 
 
 def gitGetBranch():
@@ -732,7 +784,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[65]:
+# In[149]:
 
 
 def gitGetMessage():
@@ -742,7 +794,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[66]:
+# In[150]:
 
 
 def gitGetAllFiles():
@@ -752,7 +804,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[67]:
+# In[151]:
 
 
 def gitListByTime(path=None):
@@ -768,7 +820,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[68]:
+# In[152]:
 
 
 def shellSortDirsBySize():
@@ -786,14 +838,14 @@ if is_testing():
 
 
 
-# In[69]:
+# In[153]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[70]:
+# In[154]:
 
 
 def shell(cmd):
@@ -801,7 +853,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[71]:
+# In[155]:
 
 
 if is_testing():
@@ -833,7 +885,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[72]:
+# In[156]:
 
 
 if is_testing():
@@ -843,7 +895,7 @@ description-file = README.md
 """
 
 
-# In[73]:
+# In[157]:
 
 
 if is_testing():
@@ -866,14 +918,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[74]:
+# In[158]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[75]:
+# In[159]:
 
 
 if is_testing():
@@ -882,7 +934,7 @@ if is_testing():
     
 
 
-# In[76]:
+# In[160]:
 
 
 if is_testing():
@@ -893,7 +945,7 @@ lx/__init__.py
 """
 
 
-# In[77]:
+# In[161]:
 
 
 if is_testing():
